import { BaseEvent } from '#application/base/baseEvent'
import { UUID } from '#application/types'
import CharacterHairRepository from '#repositories/characterHairRepository'

interface IPayload {
  id: UUID
}

export default class CharacterHairDeleteEvent extends BaseEvent {
  public listen(): void {
    this.socket.on('gm:characterHair:remove', this.handleEvent.bind(this))
  }

  private async handleEvent(data: IPayload, callback: (response: boolean) => void): Promise<void> {
    try {
      if (!(await this.isCharacterGM())) return

      const characterHairRepository = new CharacterHairRepository()
      const characterHair = await characterHairRepository.getById(data.id)
      if (!characterHair) return callback(false)

      await characterHair.delete()

      return callback(true)
    } catch (error) {
      this.logger.error(`Error deleting character hair ${data.id}: ${error instanceof Error ? error.message : String(error)}`)
      return callback(false)
    }
  }
}
